/* JAVASCRIPT FOR EVENT PAGE JANITZA UMG512
 * 
 * Version:  2.0
 * Date:     18-11-2019
 
EVENT REASONS:
0x0000000000000001   - Over Voltage L/N
0x0000000000000010   - Under Voltage L/N
0x0000000000000100   - Voltage Outage L/N
0x0000000000001000   - Over Current

0x0000000000100000   - Over Voltage L/L
0x0000000001000000   - Under Voltage L/L
0x0000000010000000   - Voltage Outage L/L

0x0000010000000000   - Over Frequency
0x0000100000000000   - Under Frequency
0x0001000000000000   - DT Frequency Event
0x0010000000000000   - Rapid Voltage Change L/N
0x0100000000000000   - Rapid Voltage Change L/L
0x1000000000000000   - Rapid Voltage Change Multi Phase

 */

var locked = false;
var SelectedEventElement = null;
var eventdata;
var hwwdata = null;
var firstevent = null;
var realgraphdata = {};
var graphdata = {};
var graphs = null;
var graphcnt = 0;

function initevents(){
	eventsinit();

    $('input:checkbox').change(
		function () {
		   
			if (locked) {
				alert(tl("event.wait"));
				if ($(this).is(':checked')) {
					$(this).prop('checked',false);
				} else {
					$(this).prop('checked',true);
				}
			} else {
				 $("#loader").show();
				locked = true;
				if ($(this).is(':checked')) {
					AddGraph($(this).val());
				} else {
					UpdateRealGraph();
				}
			}
		}
	);
}

////////////////////////////////////////////
// EVENTSINIT: start javascript functions
////////////////////////////////////////////
function eventsinit() {
    $.getJSON("../../../../lib/events/getevt.html", function (data) {

        var aantalevents = data['events'].length;
        eventdata = data['events'];

        var fse = true; //first selected event

		var count = 0;
        for (var i = 0; i < aantalevents; i++) {

            var evtdata = convertreason(data['events'][i][6]);
            var listitem = "<div style=\"float:right;color:#000000;padding:3px\">" + (parseInt(count) + 1) + "</div><b style=\"cursor:pointer\">"  + evtdata[1] + " - " + evtdata[2] + "</b><br>";

            var el = document.createElement("div");
            el.className = "eventitem" + ((count % 2 == 0) ? "even" : "");
            el.setAttribute("name", i);

            listitem += timestrActual(data['events'][i][0]) + " " + readableSeconds(data['events'][i][1] - data['events'][i][0]);
            el.innerHTML = listitem;
            el.onclick = eventlist_click;

            //fix to hide "future" events
            var dto = new Date();
            dto.setFullYear(dto.getFullYear() + 1);

            if ((dto.getTime() / 1000) > data['events'][i][0] && evtdata[1] != -1) {
				
                $("#list").append(el);
				count++;
                if (fse) {

                    fse = false;

                    // Fake Event in order to populate Table Info on startup
                    var fakeevent = {'target': el};
                    firstevent = fakeevent;

                }
            }
        }
		
		//Fake last item
		var listitem = tl("event.endmessage");
		var el = document.createElement("div");
		el.className = "eventitem" + ((count % 2 == 0) ? "even" : "");
		el.setAttribute("name", i);
		el.innerHTML = listitem;
		$("#list").append(el);

        hwwinit();

    });
}

function AddGraph(channel) {

    channel = parseInt(channel);
    console.log("Addgraph with channel: " + channel);
    console.log(graphdata);
    //check if it's allready available
    var art = false;
    for (var x in graphdata) {
        if (graphdata[x].channel === parseInt(channel)) {
            art = true;
        }
    }

    //if it is not there go get it
    if (art === false) {
        console.log("Graph is not available yet");
        //loop through availabe graphs
        $.getJSON("../../lib/events/mk_hww.html?_hww_nr=" + graphs[0] + "&_val_nr=" + channel, function (data) {
            //add graphdata to the array
            graphcnt++;
            graphdata[graphcnt] = data;
            //add the label to the array
            graphdata[graphcnt]['label'] = getChannelName(channel);
            graphdata[graphcnt]['channel'] = channel;
            //check if voltage or current

            if (channel === 4 || channel === 5 || channel === 6 || channel === 7) {
                graphdata[graphcnt]['yaxis'] = 2;
            }

            realgraphdata = graphdata;

            UpdateRealGraph();

        });
    } else {
        //update realgraphdata
        UpdateRealGraph();
    }
}

function UpdateRealGraph() {
    console.log("Update real graphs");
    realgraphdata = {};
    var gdc = 0;
    for (var x in graphdata) {

        if ($('#V' + graphdata[x].channel).is(':checked')) {
            realgraphdata[gdc] = graphdata[x];
            gdc++;
        }

    }

    showhww();
}

////////////////////////////////////////////
// HWWINIT: start javascript functions
////////////////////////////////////////////
function hwwinit() {

    $.getJSON("../../../../lib/events/hww.html", function (data) {

        hwwdata = data['hww'];
        eventlist_click(firstevent);
    });
}

////////////////////////////////////////////
// TIMESTRACTUAL: convert timestring to date/time
////////////////////////////////////////////
function timestrActual(i) {
    var DAYLENGTH = 24 * 60 * 60 * 1000; //24h in ms
    var past = new Date(i * 1000);
    var now = new Date();
    var tomorrowMidnight = new Date(now.getFullYear(), now.getMonth(), now.getDate() + 1);
    var todayMidnight = new Date(now.getFullYear(), now.getMonth(), now.getDate());
    var yesterdayMidnight = new Date(now.getFullYear(), now.getMonth(), now.getDate() - 1);

    //Today?
    if (past >= todayMidnight && past < tomorrowMidnight) {
        return tl("info.time.today") + ", " + PadZeros(past.getHours(), 2) + ":" + PadZeros(past.getMinutes(), 2) + ":" + PadZeros(past.getSeconds(), 2);
    }
    //Yesterday?
    if (past >= yesterdayMidnight && past < todayMidnight) {
        return tl("info.time.yesterday") + ", " + PadZeros(past.getHours(), 2) + ":" + PadZeros(past.getMinutes(), 2) + ":" + PadZeros(past.getSeconds(), 2);
    }
    return new Date(i * 1000).toLocaleString();
}


////////////////////////////////////////////
// READABLESECONDS: convert duration to sec
////////////////////////////////////////////
function readableSeconds(s)
{
    if (s > 60 * 60) {
        var h = Math.floor(s / (60 * 60));
        var m = Math.floor(s / 60) - h * 60;
        var sec = Math.runde((s - (h * 60 * 60 + m * 60)), 2);
        return  h + "h " + m + "m " + sec + "s";
    }
    if (s > 60) {
        var m = Math.floor(s / (60));
        var sec = Math.runde((s - m * 60), 2);
        return m + "m " + sec + "s";
    }

    return Math.runde(s, 2) + "s";
}


function bittest(num, bit){
    return ((num>>bit) % 2 != 0)
}

function bitclear(num, bit){
    return num & ~(1<<bit);
}

////////////////////////////////////////////
// CONVERTREASON: convert event reason to unit, type and phase
////////////////////////////////////////////
function convertreason(reason) {

    var voltage = false;
    var evtdata = new Array(4);

    console.log("reason: " + reason);       
    //console.log("reasonhex: " + reason.toString(16));
	//console.log("reasonhex2: " + parseInt(reason , 10).toString(16).toUpperCase());

    //var eventcode = parseInt(reason.toString(16));
	var phase = 0;
	
	if(reason == 0){
		evtdata[0] = "-";
        evtdata[1] = -1
        evtdata[2] = -1
        evtdata[3] = -1
        return evtdata;
	}
	
	if(reason >= 268435456){
		phase = reason / 268435456 ;
	    phase = parseInt(phase + 100);
		evtdata[0] = "V";
		evtdata[1] = tl("events.UOUTLN");
        evtdata[2] = HexToPhase(phase);
        evtdata[3] = HexToCode(phase, 1);
	}else{
		if(reason >= 16777216){
			if(bittest(reason,0)){
				phase = reason / 16777216;
				phase = parseInt(phase + 100);
				evtdata[0] = "V";
				evtdata[1] = tl("events.URVCLN");
				evtdata[2] = HexToPhase(phase);
				evtdata[3] = HexToCode(phase, 1);
			}else{
				phase = reason / 16777216;
				phase = parseInt(phase + 100);
				evtdata[0] = "V";
				evtdata[1] = tl("events.UMINLN");
				evtdata[2] = HexToPhase(phase);
				evtdata[3] = HexToCode(phase, 1);
			}
		}else{
			if(reason >= 1048576){
				if(bittest(reason,0)){
					var helper = bitclear(reason, 0)
	  	  	    	phase = parseInt(helper / 1048576);
					evtdata[0] = "V";
					evtdata[1] = tl("events.URVCLN");
					evtdata[2] = HexToPhase(phase);
					evtdata[3] = HexToCode(phase, 1);
				}else{
					phase = reason / 1048576;
					phase = parseInt(phase + 100);
					evtdata[0] = "V";
					evtdata[1] = tl("events.UMAXLN");
					evtdata[2] = HexToPhase(phase);
					evtdata[3] = HexToCode(phase, 1);
				}
			}else{
				if(reason >= 4096){
					phase = parseInt(reason / 4096);
					evtdata[0] = "A";
					evtdata[1] = tl("events.IMAX");
					evtdata[2] = HexToPhase(phase);
					evtdata[3] = HexToCode(phase, 2);
				}else{
					if(reason >= 256){
						phase = parseInt(reason / 256);
						evtdata[0] = "V";
						evtdata[1] = tl("events.UOUTLN");
						evtdata[2] = HexToPhase(phase);
						evtdata[3] = HexToCode(phase, 1);
					}else{
						if(reason >= 16){
							phase = parseInt(reason / 16);
							evtdata[0] = "V";
							evtdata[1] = tl("events.UMINLN");
							evtdata[2] = HexToPhase(phase);
							evtdata[3] = HexToCode(phase, 1);
						}else{
							phase = parseInt(reason);
							evtdata[0] = "V";
							evtdata[1] = tl("events.UMAXLN");
							evtdata[2] = HexToPhase(phase);
							evtdata[3] = HexToCode(phase, 1);
						}
					}
				}
			}
		}
	}
	
	/*
	
	  	if reason >= 268435456 then 
	    phase = info_evt.grund / 268435456 ;
	    phase = phase + 100;
		cp_tp2_c$[evt_slot] = _cp_u_zerro
        else 
   		if info_evt.grund >= 16777216 then 
			if bittest(info_evt.grund, 0) then 
		  	phase = info_evt.grund / 16777216;
			phase = phase + 100;
				cp_tp2_c$[evt_slot] = _cp_u_quick
			else		
			  	phase = info_evt.grund / 16777216;
				phase = phase + 100;
		    cp_tp2_c$[evt_slot] = _cp_u_min
			endif
  	  	else 
   		    if info_evt.grund >= 1048576 then 
				if bittest(info_evt.grund, 0) then 
					helper = bitclear(info_evt.grund, 0)
	  	  	    	phase = helper / 1048576;
					cp_tp2_c$[evt_slot] = _cp_u_quick
				else
	  	  	    phase = info_evt.grund / 1048576;
			    phase = phase + 100;
		    	cp_tp2_c$[evt_slot] = _cp_u_max
				endif
  	  		else 
    		        if info_evt.grund >= 4096 then 
	  	  	        phase = info_evt.grund / 4096;
			        cp_tp2_c$[evt_slot] = _cp_i_max
  	  		    else 
 	  		        if info_evt.grund >= 256 then 
			            phase = info_evt.grund / 256;
  		    	            cp_tp2_c$[evt_slot] = _cp_u_zerro
    			        else  
  	  		            if info_evt.grund >= 16 then 
		  	                phase = info_evt.grund / 16;
			                cp_tp2_c$[evt_slot] = _cp_u_min
			            else 
			                phase = info_evt.grund;
			                cp_tp2_c$[evt_slot] = _cp_u_max
  			            endif
	  		        endif
	    	           endif
			endif
		endif
	endif
	
	
	if(eventcode == 0){
		evtdata[0] = "-";
        evtdata[1] = -1
        evtdata[2] = -1
        evtdata[3] = -1
        return evtdata;
	}
	
    //Over Voltage L/N
    if (eventcode < 10) {
        evtdata[0] = "V";
        evtdata[1] = tl("events.UMAXLN");
        evtdata[2] = HexToPhase(eventcode,1);
        evtdata[3] = HexToCode(eventcode, 1);
        return evtdata;
    }
    eventcode = eventcode / 10;

	//Under Voltage L/N
    if (eventcode < 10) {
        evtdata[0] = "V";
        evtdata[1] = tl("events.UMINLN");
        evtdata[2] = HexToPhase(eventcode,1);
        evtdata[3] = HexToCode(eventcode, 1);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Voltage Outage L/N
    if (eventcode < 10) {
        evtdata[0] = "V";
        evtdata[1] = tl("events.UOUTLN");
        evtdata[2] = HexToPhase(eventcode,1);
        evtdata[3] = HexToCode(eventcode, 1);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Over Current
    if (eventcode < 10) {
        evtdata[0] = "A";
        evtdata[1] = tl("events.IMAX");
        evtdata[2] = HexToPhase(eventcode,1);
        evtdata[3] = HexToCode(eventcode, 1);
        return evtdata;
    }
	
    eventcode = eventcode / 10;
	eventcode = eventcode / 10;
	
	//Over Voltage L/L
    if (eventcode < 10) {
        evtdata[0] = "V";
        evtdata[1] = tl("events.UMAXLL");
        evtdata[2] = HexToPhase(eventcode,2);
        evtdata[3] = HexToCode(eventcode, 2);
        return evtdata;
    }
    eventcode = eventcode / 10;

	//Under Voltage L/L
    if (eventcode < 10) {
        evtdata[0] = "V";
        evtdata[1] = tl("events.UMINLL");
        evtdata[2] = HexToPhase(eventcode,2);
        evtdata[3] = HexToCode(eventcode, 2);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Voltage Outage L/L
    if (eventcode < 10) {
        evtdata[0] = "V";
        evtdata[1] = tl("events.UOUTLL");
        evtdata[2] = HexToPhase(eventcode,2);
        evtdata[3] = HexToCode(eventcode, 2);
        return evtdata;
    }
    eventcode = eventcode / 10;
	eventcode = eventcode / 10;
	eventcode = eventcode / 10;
	
	//Over Frequency
    if (eventcode < 10) {
        evtdata[0] = "Hz";
        evtdata[1] = tl("events.FMAX");
        evtdata[2] = HexToPhase(eventcode,0);
        evtdata[3] = HexToCode(eventcode, 0);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Under Frequency
    if (eventcode < 10) {
        evtdata[0] = "Hz";
        evtdata[1] = tl("events.FMIN");
        evtdata[2] = HexToPhase(eventcode,0);
        evtdata[3] = HexToCode(eventcode, 0);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Delta Frequency Event
    if (eventcode < 10) {
        evtdata[0] = "Hz";
        evtdata[1] = tl("events.FDELTA");
        evtdata[2] = HexToPhase(eventcode,0);
        evtdata[3] = HexToCode(eventcode, 0);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Rapid Voltage Change L/N
    if (eventcode < 10) {
        evtdata[0] = "Hz";
        evtdata[1] = tl("events.URVCLN");
        evtdata[2] = HexToPhase(eventcode,1);
        evtdata[3] = HexToCode(eventcode, 1);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Rapid Voltage Change L/L
    if (eventcode < 10) {
        evtdata[0] = "Hz";
        evtdata[1] = tl("events.URVCLL");
        evtdata[2] = HexToPhase(eventcode,2);
        evtdata[3] = HexToCode(eventcode, 2);
        return evtdata;
    }
    eventcode = eventcode / 10;
	
	//Rapid Voltage Change MP
    if (eventcode < 10) {
        evtdata[0] = "Hz";
        evtdata[1] = tl("events.URVCMP");
        evtdata[2] = HexToPhase(eventcode,3);
        evtdata[3] = HexToCode(eventcode, 3);
        return evtdata;
    }
	*/
    return evtdata;
}

////////////////////////////////////////////
// HEXTOPHASE: convert hex to phase
////////////////////////////////////////////
function HexToPhase(phase) {
	
	switch(phase) {
		case 1: 
			return "L1";
			break;
		case 2: 
			return "L2";
			break;
		case 4: 
			return "L3";
			break;
		case 8: 
			return "L4";
			break;
		case 101: 
			return "L1-L2";
			break;
		case 102: 
			return "L2-L3";
			break;
		case 104: 
			return "L3-L1";
			break;
			
	}
	
	
	
	/*
	switch(et) {
		case 0: //- frequency
			return "";
			break;
		case 1: //L/N
			switch(i) {
				case 1:
					return "L1";
					break;
				case 2:
					return "L2";
					break;
				case 4:
					return "L3";
					break;
				case 8:
					return "L4";
					break;
			}	
			break;
		case 2: //L/L
			switch(i) {
				case 1:
					return "L1-L2";
					break;
				case 2:
					return "L2-L3";
					break;
				case 4:
					return "L3-L1";
					break;
			}	
			break;
		case 3:	//Multi-phase
			return "MP";
			break;
		case 4: //Current
			switch(i) {
				case 1:
					return "L1";
					break;
				case 2:
					return "L2";
					break;
				case 4:
					return "L3";
					break;
				case 8:
					return "L4";
					break;
			}	
			break;
	}
	*/
}

////////////////////////////////////////////
// HEXTOPHASE: convert hex to graph
////////////////////////////////////////////
function HexToCode(phase, unit) {
	
	if(unit == 1){ //voltage
		switch(phase) {
			case 1: 
				return 0
				break;
			case 2: 
				return 1
				break;
			case 4: 
				return 2
				break;
			case 8: 
				return 3
				break;
			case 101: 
				return 16
				break;
			case 102: 
				return 17
				break;
			case 104: 
				return 18
				break;
				
		}
	}else{
		switch(phase) {
			case 1: 
				return 0
				break;
			case 2: 
				return 1
				break;
			case 4: 
				return 2
				break;
			case 8: 
				return 3
				break;
		}
	}
}

function PadZeros(i, len) {
    var s = i.toString();
    var erg = "";
    for (var d = 0; d < len - s.length; d++)
        erg += "0";
    return erg + s;
}


function eventlist_click(evt) {

    console.log('Op event geklikt');
    if (locked) {
        alert(tl("event.wait"));
    } else {
        locked = true;
        $("#eventgraph").empty();
        $("#overviewLegend").empty();
        $("#loader").show();

        evt = (evt) ? evt : ((window.event) ? window.event : "");
        var elem = evt.target;
        var iHWW = parseInt(elem.getAttribute("Name"));
        if(isNaN(iHWW)){
            elem = evt.target.parentNode;
            iHWW = parseInt(elem.getAttribute("Name"));
        }

        if (SelectedEventElement) {
            removeStyleClass(SelectedEventElement, "eventitem_selected");
        }

        var iHWW = parseInt(elem.getAttribute("name"));
        var evtdata = convertreason(eventdata[iHWW][6]);

        fillspan("info_starttime", timestrActual(eventdata[iHWW][0]));
        fillspan("info_duration", readableSeconds(eventdata[iHWW][1] - eventdata[iHWW][0]));
        fillspan("info_phase", "L" + evtdata[2]);
        fillspan("info_bound", String(eventdata[iHWW][2]).replace(/\./, getDecimalPoint()) + " " + evtdata[0]);
        fillspan("info_maxval", String(eventdata[iHWW][3]).replace(/\./, getDecimalPoint()) + " " + evtdata[0]);
        fillspan("info_minval", String(eventdata[iHWW][4]).replace(/\./, getDecimalPoint()) + " " + evtdata[0]);
        fillspan("info_avg", String(eventdata[iHWW][5]).replace(/\./, getDecimalPoint()) + " " + evtdata[0]);
        fillspan("info_reason", evtdata[1]);

        //Grafieklijnen (HWW's) zoeken bij event
        graphs = FindHwwForEvent(eventdata[iHWW]);

        graphdata = {};
        GetGraphData(evtdata[3]);


        addStyleClass(elem, "eventitem_selected");
        SelectedEventElement = elem;
    }
}

function fillspan(id, txt) {
    var obj = document.getElementById(id);
    if (obj)
        obj.innerHTML = txt;
}

function FindHwwForEvent(Event) {
    var list = [];


    for (var i in hwwdata) {
        if (i in Array.prototype) {
            continue;
        }
        if (Event[0] < hwwdata[i][1] && Event[1] > hwwdata[i][0]) {
            list.push(parseInt(i));
        }
    }
    return list;
}

///////////////////////////////////////
// Loops through the available graphs for the selected event and downloads the data
///////////////////////////////////////
function GetGraphData(channel) {

    $('#V0').prop("checked", false);
    $('#V1').prop("checked", false);
    $('#V2').prop("checked", false);
    $('#V3').prop("checked", false);
    $('#V4').prop("checked", false);
    $('#V5').prop("checked", false);
    $('#V6').prop("checked", false);
    $('#V7').prop("checked", false);
    $('#V16').prop("checked", false);
    $('#V17').prop("checked", false);
    $('#V18').prop("checked", false);

    $('#V' + channel).prop("checked", true);

    var graphcount = graphs.length;

    if (graphcount > 1) {
        graphcount = 1;
    }
    ;

    if (graphcount === 0) {
        $("#eventgraph").empty();
        $("#eventgraph").html("<div style='text-align: center;padding-top: 75px;'>" + tl("event.nodata") + "</div>");
        $("#loader").hide();

        locked = false;
    } else {


        $.getJSON("../../lib/events/mk_hww.html?_hww_nr=" + graphs[0] + "&_val_nr=" + channel, function (data) {
            //add graphdata to the array
            graphdata[graphcnt] = data;
            //add the label to the array
            graphdata[graphcnt]['label'] = getChannelName(channel);
            graphdata[graphcnt]['channel'] = channel;
            //check if voltage or current

            if (channel === 4 || channel === 5 || channel === 6 || channel === 7) {
                graphdata[graphcnt]['yaxis'] = 2;
            }

            realgraphdata = graphdata;

            showhww();

        });

    }
}

function getChannelName(i) {
    switch (i) {
        case 0:
            return tl("menu.voltage") + " " + tl("L1");
        case 4:
            return tl("menu.current") + " " + tl("L1");
        case 1:
            return tl("menu.voltage") + " " + tl("L2");
        case 5:
            return tl("menu.current") + " " + tl("L2");
        case 2:
            return tl("menu.voltage") + " " + tl("L3");
        case 6:
            return tl("menu.current") + " " + tl("L3");
        case 3:
            return tl("menu.voltage") + " " + tl("L4");
        case 7:
            return tl("menu.current") + " " + tl("L4");
        default:
            return i;
    }
}


function showhww() {

    var i = 0;

    $("#loader").hide();
    locked = false;
    var container = document.getElementById('eventgraph');
    var d1 = [];
    var i, graph;

    var options = {
        linewidth: 1,
        xaxis: {
            minorTickFreq: 4,
            mode: "time",
            timeMode: "local",
            timeUnit: 'second'
        },
        yaxis: {
            tickFormatter: function (val, axis) {
                return val + "V";
            },
            autoscale: true
        },
        y2axis: {
            tickFormatter: function (val, axis) {
                return val + "A";
            },
            autoscale: true
        },
        grid: {
            minorVerticalLines: true
        },
        mouse: {
            track: true,
            relative: true,
            sensibility: 10,
            radius: 5,
            trackFormatter: function (obj) {

                var time = new Date(obj.nearest.x * 1000);
                var val = obj.nearest.series.label;
                var unit = "";
                if (obj.series.yaxis.n === 1) {
                    unit = "V"
                } else {
                    unit = "A"
                }

                return val + ', X: ' + dateFormat(time, "HH:MM:ss.l") + ', Y: ' + obj.y + unit;
            }
        },
        selection: {
            mode: 'x',
            fps: 30
        }, legend: {
            position: 'se'
        }
    };


    /// Draw graph with default options, overwriting with passed options
    function drawGraph(opts) {

        var data = realgraphdata;

        // Clone the options, so the 'options' variable always keeps intact.
        var o = Flotr._.extend(Flotr._.clone(options), opts || {});

        // Return a new graph.
        return Flotr.draw(container, data, o);
    }

    // Actually draw the graph.
    drawGraph();

    // Hook into the 'flotr:select' event.
    Flotr.EventAdapter.observe(container, 'flotr:select', function (area) {

        // Draw graph with new area
        graph = drawGraph({
            xaxis: {
                min: area.x1,
                max: area.x2,
                minorTickFreq: 4,
                mode: "time",
                timeMode: "local",
                timeUnit: 'second'
            },
            yaxis: {
                min: area.y1,
                max: area.y2,
                tickFormatter: function (val, axis) {
                    return val + "V";
                },
                autoscale: true
            }
        });
    });

    // When graph is clicked, draw the graph with default area.
    Flotr.EventAdapter.observe(container, 'flotr:click', function () {
        drawGraph();
    });

}

function addStyleClass(elem, cssClassName) {

    if (elem.className.indexOf(cssClassName) < 0)
        elem.className += " " + cssClassName;
}


function removeStyleClass(elem, cssClassName) {
    elem.className = elem.className.replace(cssClassName, "");
}