const convertReason = require("../../../html/lib/events/events").convertReason;
global.tl = x => nameMapping.get(x);

test('test convertreason over voltage events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000000000001- 00000001 - 00000000  - Over Voltage L/N
    */
    const eventL1 = convertReason(...toDecimal('00000001', '00000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Over voltage');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000002', '00000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Over voltage');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000004', '00000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Over voltage');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason under voltage events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000000000010- 00000010 - 00000000  - Under Voltage L/N
    */
    const eventL1 = convertReason(...toDecimal('00000010', '00000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Under voltage');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000020', '00000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Under voltage');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000040', '00000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Under voltage');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason voltage outage events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000000000100- 00000100 - 00000000  - Voltage Outage L/N
    */
    const eventL1 = convertReason(...toDecimal('00000100', '00000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Voltage outage');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000200', '00000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Voltage outage');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000400', '00000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Voltage outage');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason over current events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000000001000- 00001000 - 00000000  - Over Current
    */
    const eventL1 = convertReason(...toDecimal('00001000', '00000000'));
    expect(eventL1[0]).toBe('A');
    expect(eventL1[1]).toBe('Over current');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(4);

    const eventL2 = convertReason(...toDecimal('00002000', '00000000'));
    expect(eventL2[0]).toBe('A');
    expect(eventL2[1]).toBe('Over current');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(5);

    const eventL3 = convertReason(...toDecimal('00004000', '00000000'));
    expect(eventL3[0]).toBe('A');
    expect(eventL3[1]).toBe('Over current');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(6);
});

test('test convertreason over voltage ll events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000000100000- 00100000 - 00000000  - Over Voltage L/L
    */
    const eventL1 = convertReason(...toDecimal('00100000', '00000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Over voltage');
    expect(eventL1[2]).toBe('L1-L2');
    expect(eventL1[3]).toBe(16);

    const eventL2 = convertReason(...toDecimal('00200000', '00000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Over voltage');
    expect(eventL2[2]).toBe('L2-L3');
    expect(eventL2[3]).toBe(17);

    const eventL3 = convertReason(...toDecimal('00400000', '00000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Over voltage');
    expect(eventL3[2]).toBe('L3-L1');
    expect(eventL3[3]).toBe(18);
});

test('test convertreason under voltage ll events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000001000000- 01000000 - 00000000  - Under Voltage L/L
    */
    const eventL1 = convertReason(...toDecimal('01000000', '00000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Under voltage');
    expect(eventL1[2]).toBe('L1-L2');
    expect(eventL1[3]).toBe(16);

    const eventL2 = convertReason(...toDecimal('02000000', '00000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Under voltage');
    expect(eventL2[2]).toBe('L2-L3');
    expect(eventL2[3]).toBe(17);

    const eventL3 = convertReason(...toDecimal('04000000', '00000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Under voltage');
    expect(eventL3[2]).toBe('L3-L1');
    expect(eventL3[3]).toBe(18);
});

test('test convertreason voltage outage ll events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000000010000000- 10000000 - 00000000  - Voltage Outage L/L
    */
    const eventL1 = convertReason(...toDecimal('10000000', '00000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Voltage outage');
    expect(eventL1[2]).toBe('L1-L2');
    expect(eventL1[3]).toBe(16);

    const eventL2 = convertReason(...toDecimal('20000000', '00000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Voltage outage');
    expect(eventL2[2]).toBe('L2-L3');
    expect(eventL2[3]).toBe(17);

    const eventL3 = convertReason(...toDecimal('40000000', '00000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Voltage outage');
    expect(eventL3[2]).toBe('L3-L1');
    expect(eventL3[3]).toBe(18);
});

test('test convertreason over frequenzy events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000010000000000- 00000000 - 00000100  - Over Frequency
    */
    const eventL1 = convertReason(...toDecimal('00000000', '00000100'));
    expect(eventL1[0]).toBe('Hz');
    expect(eventL1[1]).toBe('Over frequency');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000000', '00000200'));
    expect(eventL2[0]).toBe('Hz');
    expect(eventL2[1]).toBe('Over frequency');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000000', '00000400'));
    expect(eventL3[0]).toBe('Hz');
    expect(eventL3[1]).toBe('Over frequency');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason under frequenzy events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0000100000000000- 00000000 - 00001000  - Under Frequency
    */
    const eventL1 = convertReason(...toDecimal('00000000', '00001000'));
    expect(eventL1[0]).toBe('Hz');
    expect(eventL1[1]).toBe('Under frequency');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000000', '00002000'));
    expect(eventL2[0]).toBe('Hz');
    expect(eventL2[1]).toBe('Under frequency');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000000', '00004000'));
    expect(eventL3[0]).toBe('Hz');
    expect(eventL3[1]).toBe('Under frequency');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason frequenzy delta events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0001000000000000- 00000000 - 00010000  - DT Frequency Event
    */
    const eventL1 = convertReason(...toDecimal('00000000', '00010000'));
    expect(eventL1[0]).toBe('Hz');
    expect(eventL1[1]).toBe('Frequency delta');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000000', '00020000'));
    expect(eventL2[0]).toBe('Hz');
    expect(eventL2[1]).toBe('Frequency delta');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000000', '00040000'));
    expect(eventL3[0]).toBe('Hz');
    expect(eventL3[1]).toBe('Frequency delta');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason rapid voltage change ln events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0010000000000000- 00000000 - 00100000  - Rapid Voltage Change L/N
    */
    const eventL1 = convertReason(...toDecimal('00000000', '00100000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Rapid Voltage Change');
    expect(eventL1[2]).toBe('L1');
    expect(eventL1[3]).toBe(0);

    const eventL2 = convertReason(...toDecimal('00000000', '00200000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Rapid Voltage Change');
    expect(eventL2[2]).toBe('L2');
    expect(eventL2[3]).toBe(1);

    const eventL3 = convertReason(...toDecimal('00000000', '00400000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Rapid Voltage Change');
    expect(eventL3[2]).toBe('L3');
    expect(eventL3[3]).toBe(2);
});

test('test convertreason rapid voltage change ll events', () => {
    /*
    HEX 64 bit        - HEX_LO   - HEX_HI
    0x0100000000000000- 00000000 - 01000000  - Rapid Voltage Change L/L
    */
    const eventL1 = convertReason(...toDecimal('00000000', '01000000'));
    expect(eventL1[0]).toBe('V');
    expect(eventL1[1]).toBe('Rapid Voltage Change');
    expect(eventL1[2]).toBe('L1-L2');
    expect(eventL1[3]).toBe(16);

    const eventL2 = convertReason(...toDecimal('00000000', '02000000'));
    expect(eventL2[0]).toBe('V');
    expect(eventL2[1]).toBe('Rapid Voltage Change');
    expect(eventL2[2]).toBe('L2-L3');
    expect(eventL2[3]).toBe(17);

    const eventL3 = convertReason(...toDecimal('00000000', '04000000'));
    expect(eventL3[0]).toBe('V');
    expect(eventL3[1]).toBe('Rapid Voltage Change');
    expect(eventL3[2]).toBe('L3-L1');
    expect(eventL3[3]).toBe(18);
});

const toDecimal = (hexLo, hexHi) => [parseInt(hexLo, 16), parseInt(hexHi, 16)];

const nameMapping = new Map();
nameMapping.set("events.UMAXLN", "Over voltage");
nameMapping.set("events.UMINLN", "Under voltage");
nameMapping.set("events.UOUTLN", "Voltage outage");
nameMapping.set("events.IMAX", "Over current");
nameMapping.set("events.UMAXLL", "Over voltage");
nameMapping.set("events.UMINLL", "Under voltage");
nameMapping.set("events.UOUTLL", "Voltage outage");
nameMapping.set("events.FMAX", "Over frequency");
nameMapping.set("events.FMIN", "Under frequency");
nameMapping.set("events.FDELTA", "Frequency delta");
nameMapping.set("events.URVCLN", "Rapid Voltage Change");
nameMapping.set("events.URVCLL", "Rapid Voltage Change");
nameMapping.set("events.URVCMP", "Rapid Voltage Change");